/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package com.acme.ejb3.service;

import java.io.Serializable;

import javax.ejb.Remote;

import org.jboss.annotation.ejb.Management;
import org.jboss.annotation.ejb.Service;
import org.jboss.logging.Logger;

import com.acme.pojo.Replicate;
import com.acme.pojo.SimpleReplicator;

/**
 * TimeTellerService.
 * 
 * @author <a href="mailto:galder.zamarreno@jboss.com">Galder Zamarreno</a>
 */
@Service(objectName="com.acme:service=Cache")
@Management(CacheManagement.class)
@Remote(Cache.class)
public class CacheService implements CacheManagement
{
   private static final Logger log = Logger.getLogger(CacheService.class);
   
   private Replicate replicate;
   
   public void start() throws Exception
   {
      replicate = new SimpleReplicator();
   }

   public Object replicate(CacheMode mode, Serializable object) throws Exception
   {
      log.info("invoke[" + mode +"], with object[" + object + "]");
      return mode.replicate(object, replicate);
   }
}
